#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 byte-order
version:              0.1.3.1
visibility:           public
id:                   byte-order-0.1.3.1-KeerSSU075eAHcR0uTVsqG
key:                  byte-order-0.1.3.1-KeerSSU075eAHcR0uTVsqG
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           amartin@layer3com.com
author:               Andrew Martin
homepage:             https://github.com/byteverse/byte-order
synopsis:             Portable big-endian and little-endian conversions
description:
    This library provides an interface to portably work with byte
    arrays whose contents are known to be of a fixed endianness.
    There are two ways to use this module. See the `System.ByteOrder`
    module for more documentation.

category:             Data
abi:                  725324393267f51a1807f756ffe70044
exposed:              True
exposed-modules:
    Data.Primitive.ByteArray.BigEndian
    Data.Primitive.ByteArray.LittleEndian Data.Primitive.Ptr.BigEndian
    System.ByteOrder System.ByteOrder.Class

import-dirs:          /usr/lib/ghc-9.6.6/site-local/byte-order-0.1.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/byte-order-0.1.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/byte-order-0.1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-byte-order
hs-libraries:         HSbyte-order-0.1.3.1-KeerSSU075eAHcR0uTVsqG
depends:
    base-4.18.2.1 primitive-0.9.1.0-J2dxudhiRepI2JRXVzckXt
    primitive-unaligned-0.1.1.2-KaIRjWxKGVAKqjvsrQNc1X
    wide-word-0.1.9.0-JnPpSfMfATPFNWAhIXm7Z6

haddock-interfaces:   /usr/share/doc/haskell-byte-order/html/byte-order.haddock
haddock-html:         /usr/share/doc/haskell-byte-order/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

